@@ -2,4 +2,4 @@ from .circKepZList import _ZList
 from . import palTrans
 from . import forTrans
 from .limBrightTrans import LimBrightTrans
-from .rmcl_ohta import RmcL, RmcL_Hirano
+from .rmcl_ohta import RmcL, RmcL_Hirano, RmcLell
